@@ -3,7 +3,7 @@ from typing import Any, Dict, List, Optional
 from pydantic import validator
 
 from pydantic import Field
-from deeplabel.basemodel import MixinConfig, DeeplabelBase
+from deeplabel.basemodel import DeeplabelBase
 import deeplabel.client
 
 
@@ -28,10 +28,10 @@ class DetectionLabel(DeeplabelBase):
     client:Any = Field(None, exclude=True)
 
     @validator('label_id', always=True)
-    def validate_label_id(cls, v, values):
+    def validate_label_id(cls, v:Optional[str], values)->str: #type: ignore
         if v is None:
             assert 'id' in values, f"DetectionLabel should either have label_id or id key. {v} ; {values}"
-            return values['id']
+            return values['id'] #type: ignore
         return v
 
     @classmethod
